@@ -12,29 +12,68 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import warnings
-from typing import List, Optional, Union
+from functools import wraps
+from typing import Callable, List, Optional, Union
 
-import pytorch_lightning as pl
+import torch
+from pytorch_lightning import LightningDataModule, LightningModule, Trainer
 from pytorch_lightning.callbacks import BaseFinetuning
-from pytorch_lightning.core.lightning import LightningModule
 from pytorch_lightning.utilities import rank_zero_warn
+from pytorch_lightning.utilities.argparse import get_init_arguments_and_types, parse_env_variables
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
 from torch.utils.data import DataLoader
 
+import flash
 from flash.core.finetuning import _DEFAULTS_FINETUNE_STRATEGIES, instantiate_default_finetuning_callbacks
 
 
-class Trainer(pl.Trainer):
+def _defaults_from_env_vars(fn: Callable) -> Callable:
+    """Copy of ``pytorch_lightning.trainer.connectors.env_vars_connector._defaults_from_env_vars``. Required to fix
+    build error in readthedocs."""
+
+    @wraps(fn)
+    def insert_env_defaults(self, *args, **kwargs):
+        cls = self.__class__  # get the class
+        if args:  # inace any args passed move them to kwargs
+            # parse only the argument names
+            cls_arg_names = [arg[0] for arg in get_init_arguments_and_types(cls)]
+            # convert args to kwargs
+            kwargs.update({k: v for k, v in zip(cls_arg_names, args)})
+        env_variables = vars(parse_env_variables(cls))
+        # update the kwargs by env variables
+        kwargs = dict(list(env_variables.items()) + list(kwargs.items()))
+
+        # all args were already moved to kwargs
+        return fn(self, **kwargs)
+
+    return insert_env_defaults
+
+
+class Trainer(Trainer):
+
+    @_defaults_from_env_vars
+    def __init__(self, *args, **kwargs):
+        if flash._IS_TESTING:
+            if torch.cuda.is_available():
+                kwargs["gpus"] = 1
+                kwargs["max_epochs"] = 3
+                kwargs["limit_train_batches"] = 1.0
+                kwargs["limit_val_batches"] = 1.0
+                kwargs["limit_test_batches"] = 1.0
+                kwargs["fast_dev_run"] = False
+            else:
+                kwargs["fast_dev_run"] = True
+        super().__init__(*args, **kwargs)
 
     def fit(
         self,
-        model: pl.LightningModule,
+        model: LightningModule,
         train_dataloader: Optional[DataLoader] = None,
         val_dataloaders: Optional[Union[DataLoader, List[DataLoader]]] = None,
-        datamodule: Optional[pl.LightningDataModule] = None,
+        datamodule: Optional[LightningDataModule] = None,
     ):
         r"""
-        Runs the full optimization routine. Same as pytorch_lightning.Trainer().fit()
+        Runs the full optimization routine. Same as :meth:`pytorch_lightning.Trainer.fit`
 
         Args:
             datamodule: A instance of :class:`LightningDataModule`.
@@ -57,12 +96,12 @@ class Trainer(pl.Trainer):
         model: LightningModule,
         train_dataloader: Optional[DataLoader] = None,
         val_dataloaders: Optional[Union[DataLoader, List[DataLoader]]] = None,
-        datamodule: Optional[pl.LightningDataModule] = None,
+        datamodule: Optional[LightningDataModule] = None,
         strategy: Optional[Union[str, BaseFinetuning]] = None,
     ):
         r"""
 
-        Runs the full optimization routine. Same as pytorch_lightning.Trainer().fit(), but unfreezes layers
+        Runs the full optimization routine. Same as :meth:`pytorch_lightning.Trainer.fit`, but unfreezes layers
         of the backbone throughout training layers of the backbone throughout training.
 
         Args:
@@ -70,21 +109,21 @@ class Trainer(pl.Trainer):
 
             model: Model to fit.
 
-            train_dataloader: A Pytorch DataLoader with training samples. If the model has
+            train_dataloader: A PyTorch DataLoader with training samples. If the model has
                 a predefined train_dataloader method this will be skipped.
 
-            val_dataloaders: Either a single Pytorch Dataloader or a list of them, specifying validation samples.
+            val_dataloaders: Either a single PyTorch Dataloader or a list of them, specifying validation samples.
                 If the model has a predefined val_dataloaders method this will be skipped
 
             strategy: Should either be a string or a finetuning callback subclassing
-                ``pytorch_lightning.callbacks.BaseFinetuning``.
+                :class:`pytorch_lightning.callbacks.BaseFinetuning`.
 
-                Currently, default strategies can be enabled with these strings:
-                    - ``no_freeze``,
-                    - ``freeze``,
-                    - ``freeze_unfreeze``,
-                    - ``unfreeze_milestones``
+                Default strategies can be enabled with these strings:
 
+                - ``"no_freeze"``,
+                - ``"freeze"``,
+                - ``"freeze_unfreeze"``,
+                - ``"unfreeze_milestones"``.
         """
         self._resolve_callbacks(model, strategy)
         return super().fit(model, train_dataloader, val_dataloaders, datamodule)
