@@ -13,14 +13,17 @@
 # limitations under the License.
 import os
 import warnings
-from typing import Callable, Mapping, Sequence, Type, Union
+from typing import Any, Callable, Dict, List, Mapping, Optional, Sequence, Type, Union
 
 import torch
-from torchmetrics import Accuracy
-from transformers import BertForSequenceClassification
 
-from flash.core.classification import ClassificationDataPipeline, ClassificationTask
-from flash.text.classification.data import TextClassificationData
+from flash.core.classification import ClassificationTask
+from flash.core.data.process import Serializer
+from flash.core.utilities.imports import _TEXT_AVAILABLE
+
+if _TEXT_AVAILABLE:
+    from transformers import BertForSequenceClassification
+    from transformers.modeling_outputs import SequenceClassifierOutput
 
 
 class TextClassifier(ClassificationTask):
@@ -32,16 +35,23 @@ class TextClassifier(ClassificationTask):
         optimizer: Optimizer to use for training, defaults to `torch.optim.Adam`.
         metrics: Metrics to compute for training and evaluation.
         learning_rate: Learning rate to use for training, defaults to `1e-3`
+        multi_label: Whether the targets are multi-label or not.
+        serializer: The :class:`~flash.core.data.process.Serializer` to use when serializing prediction outputs.
     """
 
     def __init__(
         self,
         num_classes: int,
-        backbone: str = "prajjwal1/bert-tiny",
+        backbone: str = "prajjwal1/bert-medium",
         optimizer: Type[torch.optim.Optimizer] = torch.optim.Adam,
-        metrics: Union[Callable, Mapping, Sequence, None] = [Accuracy()],
-        learning_rate: float = 1e-3,
+        metrics: Union[Callable, Mapping, Sequence, None] = None,
+        learning_rate: float = 1e-2,
+        multi_label: bool = False,
+        serializer: Optional[Union[Serializer, Mapping[str, Serializer]]] = None,
     ):
+        if not _TEXT_AVAILABLE:
+            raise ModuleNotFoundError("Please, pip install -e '.[text]'")
+
         self.save_hyperparameters()
 
         os.environ["TOKENIZERS_PARALLELISM"] = "TRUE"
@@ -56,6 +66,8 @@ class TextClassifier(ClassificationTask):
             optimizer=optimizer,
             metrics=metrics,
             learning_rate=learning_rate,
+            multi_label=multi_label,
+            serializer=serializer,
         )
         self.model = BertForSequenceClassification.from_pretrained(backbone, num_labels=num_classes)
 
@@ -73,10 +85,14 @@ class TextClassifier(ClassificationTask):
         loss, logits = out[:2]
         output["loss"] = loss
         output["y_hat"] = logits
-        probs = self.data_pipeline.before_uncollate(logits)
+        if isinstance(logits, SequenceClassifierOutput):
+            logits = logits.logits
+        probs = torch.softmax(logits, 1)
         output["logs"] = {name: metric(probs, batch["labels"]) for name, metric in self.metrics.items()}
         return output
 
-    @staticmethod
-    def default_pipeline() -> ClassificationDataPipeline:
-        return TextClassificationData.default_pipeline()
+    def _ci_benchmark_fn(self, history: List[Dict[str, Any]]):
+        """
+        This function is used only for debugging usage with CI
+        """
+        assert history[-1]["val_accuracy"] > 0.730
