@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Callable, Mapping, Optional, Sequence, Type, Union
+from typing import Any, Callable, Dict, List, Mapping, Optional, Sequence, Type, Union
 
 import pytorch_lightning as pl
 import torch
@@ -37,7 +37,7 @@ class SummarizationTask(Seq2SeqTask):
 
     def __init__(
         self,
-        backbone: str = "t5-small",
+        backbone: str = "sshleifer/tiny-mbart",
         loss_fn: Optional[Union[Callable, Mapping, Sequence]] = None,
         optimizer: Type[torch.optim.Optimizer] = torch.optim.Adam,
         metrics: Union[pl.metrics.Metric, Mapping, Sequence, None] = None,
@@ -66,7 +66,13 @@ class SummarizationTask(Seq2SeqTask):
     def task(self) -> str:
         return "summarization"
 
-    def compute_metrics(self, generated_tokens, batch, prefix):
+    def compute_metrics(self, generated_tokens: torch.Tensor, batch: Dict, prefix: str) -> None:
         tgt_lns = self.tokenize_labels(batch["labels"])
-        result = self.rouge(generated_tokens, tgt_lns)
+        result = self.rouge(self._postprocess.uncollate(generated_tokens), tgt_lns)
         self.log_dict(result, on_step=False, on_epoch=True)
+
+    def _ci_benchmark_fn(self, history: List[Dict[str, Any]]):
+        """
+        This function is used only for debugging usage with CI
+        """
+        assert history[-1]["val_f1"] > 0.45
